using System;
using System.Collections.Generic;
using System.Text;
using PdfSharp.Pdf;
using PdfSharp.Pdf.Advanced;
using PdfSharp.Internal;
using PdfSharp.Drawing;

namespace PdfSharp.Pdf.Annotations
{
    /// <summary>
    /// Dictionary for an Annotation border style
    /// </summary>
    public sealed class PdfAnnotationBorder
    {
        private PdfDictionary _host;
        /// <summary>
        /// This is the default constructor. It constructs an instance of this thing...
        /// </summary>
        public PdfAnnotationBorder(PdfDictionary host) : base()
        {
            _host = host;
            Initialize();
        }

        void Initialize()
        {
            _host.Elements.SetName("/Type", "/Border");
        }

        /// <summary>
        /// The border width in points. If this value is 0, no border is drawn. Default value: 1.
        /// </summary>
        public int Width
        {
            get
            {
                return _host.Elements.GetInteger("/W");
            }
            set
            {
                _host.Elements.SetInteger("/W", value);
            }
        }
        
        /// <summary>
        /// The border style. Use PDFAnnotationBorderStyle for values
        /// </summary>
        public PdfName Style
        {
            get
            {
                return new PdfName(_host.Elements.GetName("/S"));
            }
            set
            {
                _host.Elements.SetName("/S", value.Value);
            }
        }

        //'/D' is dash array, but I don't need to use Dashed borders so I'm not implementing it yet.
        //        (Optional) A dash array defining a pattern of dashes and gaps to be used in drawing a 
        //dashed border (border style D above). The dash array is specified in the same format 
        //as in the line dash pattern parameter of the graphics state (see Line Dash Pattern on 
        //page 217). The dash phase is not specified and is assumed to be 0. For example, a D
        //entry of [ 3  2  ] specifies a border drawn with 3-point dashes alternating with 2-point 
        //gaps. Default value: [  3  ]. 
    }
}
