#region PDFsharp - A .NET library for processing PDF
//
// Authors:
//   PDFsharp Team (mailto:PDFsharpSupport@pdfsharp.de)
//
// Copyright (c) 2005-2008 empira Software GmbH, Cologne (Germany)
//
// http://www.pdfsharp.com
// http://sourceforge.net/projects/pdfsharp
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Diagnostics;
using System.IO;
using PdfSharp;
using PdfSharp.Drawing;
using PdfSharp.Pdf;
using PdfSharp.Pdf.IO;
using PdfSharp.Pdf.Annotations;
using PdfSharp.Pdf.Annotations.enums;
using PdfSharp.Pdf.AcroForms;

namespace Annotations
{
    /// <summary>
    /// This sample shows how to create annotations.
    /// </summary>
    class Program
    {
        [STAThread]
        static void Main(string[] args)
        {
            // Create a new PDF document
            PdfDocument document = new PdfDocument();
            XFont font = new XFont("Verdana", 14);

            // Create a page
            PdfPage page = document.AddPage();
            XGraphics gfx = XGraphics.FromPdfPage(page);
            gfx.DrawString("The first line of text, with mouse events.", font, XBrushes.Black, 30, 50, XStringFormats.Default);
            gfx.DrawString("There is no second line of text.", font, XBrushes.Black, 30, 140, XStringFormats.Default);

            // Create a PDF text annotation
            PdfFreeTextAnnotation textAnnot = new PdfFreeTextAnnotation(document);
            textAnnot.Contents = "This is the contents of the annotation.\nLineTwo";
            XRect rect = gfx.Transformer.WorldToDefaultPage(new XRect(new XPoint(30, 60), new XSize(250, 40)));
            textAnnot.Rectangle = new PdfRectangle(rect);
            textAnnot.Border.Width = 5;
            textAnnot.Border.Style = PdfAnnotationBorderStyles.Beveled;
            textAnnot.TextAlign = 1;
            page.Annotations.Add(textAnnot);
         
            //Create another annotation, just for kicks
            PdfWidgetAnnotation mouseAnot = new PdfWidgetAnnotation(document);
            mouseAnot.Contents = "Mouse over widget test!";
            rect = gfx.Transformer.WorldToDefaultPage(new XRect(new XPoint(30, 40), new XSize(280, 20)));
            mouseAnot.Elements.SetString("/T", "TestButton"); //Field name needed for this to be recognised...?
            mouseAnot.Rectangle = new PdfRectangle(rect);
            mouseAnot.Elements.SetName("/FT", "/Btn"); //Set this up as a form button.
            mouseAnot.TriggerEvents.MouseUp.ActionName = "/JavaScript";
            mouseAnot.TriggerEvents.MouseUp.Elements.SetString("/JS", "app.alert('Mouse events are working...');");
            mouseAnot.TriggerEvents.Enter.ActionName = "/Hide";
            mouseAnot.TriggerEvents.Enter.Elements.SetReference("/T", textAnnot);
            mouseAnot.TriggerEvents.Enter.Elements.SetBoolean("/H", false);
            mouseAnot.TriggerEvents.Exit.ActionName = "/Hide";
            mouseAnot.TriggerEvents.Exit.Elements.SetReference("/T", textAnnot);
            mouseAnot.TriggerEvents.Exit.Elements.SetBoolean("/H", true);
            page.Annotations.Add(mouseAnot);
            mouseAnot.AcroFormFlags = PdfAcroFieldFlags.Pushbutton;
            PdfPushButtonField butt = (PdfPushButtonField)document.AcroForm.Fields.CreateAcroField(mouseAnot);

            // Save the document...
            string filename = "Annotations.pdf";
            document.Save(filename);
            Process.Start(filename);
        }
    }
}
